# Oracle, predict the stock market 💸

<br/>

<p align="center">
  <img height="150" src="https://user-images.githubusercontent.com/61618641/147692854-f7001d42-9dca-414c-9301-819389729c43.png" alt="The Oracle logo")
</p>


<br/>
  
_Disclaimer: Information is provided 'as is' and solely for informational purposes, not for trading purposes or advice._



## How to install 📥

```py
pip install the_oracle
```

<br/>
  
## How to use ⚙️

  
Coming...